Creating Excel files with Python and XlsxWriter — XlsxWriter Documentation

### Navigation

- index
- next |
- XlsxWriter Documentation »

# Creating Excel files with Python and XlsxWriter

XlsxWriter is a Python module for creating Excel XLSX files.

(Sample code to create the above spreadsheet.)

XlsxWriter

XlsxWriter supports the following features in version 0.3.2:

- 100% compatible Excel XLSX files.
- Write text, numbers, formulas, dates to cells.
- Write hyperlinks to cells.
- Full cell formatting.
- Multiple worksheets.
- Charts.
- Page setup methods for printing.
- Merged cells.
- Defined names.
- Autofilters.
- Data validation and drop down lists.
- Conditional formatting.
- Worksheet PNG/JPEG images.
- Rich multi-format strings.
- Cell comments.
- Document properties.
- Worksheet cell protection.
- Freeze and split worksheet panes.
- Worksheet Tables.
- Sparklines.
- Outlines and Grouping.
- Memory optimisation mode for writing large files.
- Standard libraries only.
- Python 2.6, 2.7, 3.1, 3.2 and 3.3 support.

This document explains how to use the XlsxWriter module. See the following sections for more information.

- Contents

- Introduction
- Getting Started with XlsxWriter

- Tutorial 1: Create a simple XLSX file
- Tutorial 2: Adding formatting to the XLSX File
- Tutorial 3: Writing different types of data to the XLSX File

- The Workbook Class
- The Worksheet Class
- The Worksheet Class (Page Setup)
- The Format Class
- The Chart Class

- Working with Cell Notation
- Working with Formats
- Working with Dates and Time
- Working with Charts
- Working with Autofilters
- Working with Data Validation
- Working with Conditional Formatting
- Working with Worksheet Tables
- Working with Sparklines
- Working with Cell Comments
- Working with Outlines and Grouping
- Working with Memory and Performance

- Examples

- Chart Examples

- Comparison with Excel::Writer::XLSX
- Alternative modules for handling Excel files
- Known Issues and Bugs
- Reporting Bugs
- Frequently Asked Questions
- Changes in XlsxWriter
- Author
- License

### Navigation

- index
- next |
- XlsxWriter Documentation »